% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_kfas_augment.R
\name{ild_augment_states}
\alias{ild_augment_states}
\title{Per-row latent states (long format) for complex multi-state models}
\usage{
ild_augment_states(x, ...)
}
\arguments{
\item{x}{An object from [ild_kfas()].}

\item{...}{Reserved.}
}
\value{
A \code{\link[tibble]{tibble}}.
}
\description{
For \code{local_level} only, use [ild_augment()] which already provides
\code{.state} for the level. This function is reserved for future multi-state
models.
}
