% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_msm_bootstrap.R
\name{tidy_ild_msm_bootstrap}
\alias{tidy_ild_msm_bootstrap}
\title{Tidy fixed effects from \code{ild_msm_bootstrap}}
\usage{
tidy_ild_msm_bootstrap(x, conf_level = 0.95, ...)
}
\arguments{
\item{x}{Object from [ild_msm_bootstrap()].}

\item{conf_level}{Numeric. Used for implied tail quantiles (default 0.95).}

\item{...}{Unused.}
}
\value{
A tibble; see \code{\link{ild_tidy_schema}}.
}
\description{
Returns a tibble matching \code{\link{ild_tidy_schema}} with \code{interval_type}
\code{bootstrap_percentile} (equal-tailed over replicate coefficients).
}
\seealso{
[ild_msm_bootstrap()], [ild_msm_inference]
}
