% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_diagnostics.R
\name{plot_ild_diagnostics}
\alias{plot_ild_diagnostics}
\title{Plot diagnostics from an ild_diagnostics object}
\usage{
plot_ild_diagnostics(diag, type = NULL)
}
\arguments{
\item{diag}{An object returned by [ild_diagnostics()].}

\item{type}{Character vector. Which plots to build (default: the types stored in \code{diag$meta$type}).}
}
\value{
A named list of ggplot objects (e.g. \code{residual_acf}, \code{residuals_vs_fitted}, \code{residuals_vs_time}, \code{qq}).
}
\description{
Generates ggplot objects for the requested diagnostic types. Plots are not
stored in the diagnostics object; call this function to create them.
}
