% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_generics.R, R/ild_brms_s3.R,
%   R/ild_ctsem_s3.R, R/ild_kfas_autoplot.R, R/ild_autoplot_bundle.R
\name{ild_autoplot}
\alias{ild_autoplot}
\alias{ild_autoplot.ild_diagnostics}
\alias{ild_autoplot.lmerMod}
\alias{ild_autoplot.lme}
\alias{ild_autoplot.default}
\alias{ild_autoplot.brmsfit}
\alias{ild_autoplot.ild_fit_ctsem}
\alias{ild_autoplot.ild_fit_kfas}
\alias{ild_autoplot.ild_diagnostics_bundle}
\title{Autoplot for ILD model fits or diagnostics (S3 generic)}
\usage{
ild_autoplot(x, ...)

\method{ild_autoplot}{ild_diagnostics}(x, ...)

\method{ild_autoplot}{lmerMod}(x, type = "fitted_vs_actual", ...)

\method{ild_autoplot}{lme}(x, type = "fitted_vs_actual", ...)

\method{ild_autoplot}{default}(x, ...)

\method{ild_autoplot}{brmsfit}(x, type = "pp_check", ...)

\method{ild_autoplot}{ild_fit_ctsem}(x, type = c("fitted_vs_actual", "residual_time", "qq"), ...)

\method{ild_autoplot}{ild_fit_kfas}(x, type = c("states", "innovations", "signal"), ...)

\method{ild_autoplot}{ild_diagnostics_bundle}(x, section = "residual", type = NULL, ...)
}
\arguments{
\item{x}{A bundle, \code{ild_diagnostics} object, or a fitted model with \code{ild_data}.}

\item{...}{Passed to [plot_ild_diagnostics()] (\code{ild_diagnostics} objects, or bundle
\code{section = "residual"} with \code{type = NULL} and legacy diagnostics), to
[ild_plot()] (\code{lmerMod}/\code{lme}), or to \code{brms::pp_check()} (bundle
\code{section = "predictive"}, \code{type = "ppc"}).}

\item{type}{Character: \code{"states"} (smoothed level vs time), \code{"innovations"}
(standardized), or \code{"signal"} (observation expectation vs outcome).}

\item{section}{For \code{\link{ild_diagnostics_bundle}} only: \code{"residual"},
\code{"fit"}, \code{"predictive"}, \code{"data"}, \code{"design"}, or \code{"causal"}.}
}
\description{
For \code{ild_diagnostics_bundle} from [ild_diagnose()], dispatches by \code{section}
and \code{type} (section-first; see \code{?ild_autoplot} method for
\code{ild_diagnostics_bundle}). For [ild_diagnostics()], calls [plot_ild_diagnostics()]
directly. For \code{lmerMod} or \code{lme} fits from [ild_lme()], calls [ild_plot()]
(default \code{type = "fitted_vs_actual"}).
}
