% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_kfas_plot.R
\name{ild_plot_filtered_vs_smoothed}
\alias{ild_plot_filtered_vs_smoothed}
\title{Plot filtered vs smoothed state (first state)}
\usage{
ild_plot_filtered_vs_smoothed(x)
}
\arguments{
\item{x}{An object from [ild_kfas()].}
}
\value{
A \code{ggplot} object.
}
\description{
Compares one-step filtered state (\code{att}) with smoothed (\code{alphahat}) when available.
}
