% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_kfas_tidiers.R
\name{ild_tidy_states}
\alias{ild_tidy_states}
\title{Tidy per-time state summaries for ild_kfas}
\usage{
ild_tidy_states(x, ...)
}
\arguments{
\item{x}{An object from [ild_kfas()].}

\item{...}{Reserved.}
}
\value{
A \code{\link[tibble]{tibble}}.
}
\description{
Returns a tibble with one row per time index and columns for the smoothed
level (and optional variance). Separate from [ild_tidy()] which tidies
**parameters**.
}
