% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_provenance.R
\name{ild_provenance}
\alias{ild_provenance}
\title{Return the raw provenance object}
\usage{
ild_provenance(x)
}
\arguments{
\item{x}{An ILD object (see [is_ild()]) or an analysis object with \code{ild_provenance} attribute.}
}
\value{
For data: list with \code{version} and \code{steps}. For analysis: list with
  \code{version}, \code{source_data_provenance}, \code{analysis_steps}. \code{NULL} if none.
}
\description{
For ILD data: returns \code{attr(x, "tidyILD")$provenance} (version + steps from
preprocessing). For analysis objects (e.g. fits from [ild_lme()], [ild_diagnostics()],
[ild_tvem()], [ild_power()], [ild_missing_model()]): returns \code{attr(x, "ild_provenance")},
which has \code{source_data_provenance} (snapshot of data provenance) and
\code{analysis_steps} (list of analysis step records).
}
