% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild-class.R
\name{is_ild}
\alias{is_ild}
\title{Check if an object is a valid ILD tibble}
\usage{
is_ild(x)
}
\arguments{
\item{x}{Any object.}
}
\value{
Logical.
}
\description{
Returns TRUE if the object has all required `.ild_*` columns and
`ild_*` metadata attributes (as set by [ild_prepare()]).
}
