% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ild_provenance.R
\name{ild_history}
\alias{ild_history}
\title{Print a human-readable log of preprocessing or analysis steps}
\usage{
ild_history(x)
}
\arguments{
\item{x}{An ILD object (see [is_ild()]) or an analysis object with \code{ild_provenance}.}
}
\value{
The provenance object (from [ild_provenance()]) invisibly, or a message if none.
}
\description{
For ILD data, displays data provenance steps. For analysis objects (e.g. from
[ild_lme()], [ild_diagnostics()]), displays source data provenance (if any)
and analysis steps. Use [ild_provenance()] to get the raw structured object.
}
